==> telectron-1.2.23-py3-none-any.whl: telectron/raw/functions/payments/send_payment_form.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class SendPaymentForm(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``129``
        - ID: ``0x30c3bc9d``

    Parameters:
        form_id: ``int`` ``64-bit``
        peer: :obj:`InputPeer <telectron.raw.base.InputPeer>`
        msg_id: ``int`` ``32-bit``
        credentials: :obj:`InputPaymentCredentials <telectron.raw.base.InputPaymentCredentials>`
        requested_info_id (optional): ``str``
        shipping_option_id (optional): ``str``
        tip_amount (optional): ``int`` ``64-bit``

    Returns:
        :obj:`payments.PaymentResult <telectron.raw.base.payments.PaymentResult>`
    """

    __slots__: List[str] = ["form_id", "peer", "msg_id", "credentials", "requested_info_id", "shipping_option_id", "tip_amount"]

    ID = 0x30c3bc9d
    QUALNAME = "functions.payments.SendPaymentForm"

    def __init__(self, *, form_id: int, peer: "raw.base.InputPeer", msg_id: int, credentials: "raw.base.InputPaymentCredentials", requested_info_id: Union[None, str] = None, shipping_option_id: Union[None, str] = None, tip_amount: Union[None, int] = None) -> None:
        self.form_id = form_id  # long
        self.peer = peer  # InputPeer
        self.msg_id = msg_id  # int
        self.credentials = credentials  # InputPaymentCredentials
        self.requested_info_id = requested_info_id  # flags.0?string
        self.shipping_option_id = shipping_option_id  # flags.1?string
        self.tip_amount = tip_amount  # flags.2?long

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "SendPaymentForm":
        flags = Int.read(data)
        
        form_id = Long.read(data)
        
        peer = TLObject.read(data)
        
        msg_id = Int.read(data)
        
        requested_info_id = String.read(data) if flags & (1 << 0) else None
        shipping_option_id = String.read(data) if flags & (1 << 1) else None
        credentials = TLObject.read(data)
        
        tip_amount = Long.read(data) if flags & (1 << 2) else None
        return SendPaymentForm(form_id=form_id, peer=peer, msg_id=msg_id, credentials=credentials, requested_info_id=requested_info_id, shipping_option_id=shipping_option_id, tip_amount=tip_amount)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.requested_info_id is not None else 0
        flags |= (1 << 1) if self.shipping_option_id is not None else 0
        flags |= (1 << 2) if self.tip_amount is not None else 0
        data.write(Int(flags))
        
        data.write(Long(self.form_id))
        
        data.write(self.peer.write())
        
        data.write(Int(self.msg_id))
        
        if self.requested_info_id is not None:
            data.write(String(self.requested_info_id))
        
        if self.shipping_option_id is not None:
            data.write(String(self.shipping_option_id))
        
        data.write(self.credentials.write())
        
        if self.tip_amount is not None:
            data.write(Long(self.tip_amount))
        
        return data.getvalue()

==> telectron-1.2.42-py3-none-any.whl: telectron/raw/functions/payments/send_payment_form.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class SendPaymentForm(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``134``
        - ID: ``0x30c3bc9d``

    Parameters:
        form_id: ``int`` ``64-bit``
        peer: :obj:`InputPeer <telectron.raw.base.InputPeer>`
        msg_id: ``int`` ``32-bit``
        credentials: :obj:`InputPaymentCredentials <telectron.raw.base.InputPaymentCredentials>`
        requested_info_id (optional): ``str``
        shipping_option_id (optional): ``str``
        tip_amount (optional): ``int`` ``64-bit``

    Returns:
        :obj:`payments.PaymentResult <telectron.raw.base.payments.PaymentResult>`
    """

    __slots__: List[str] = ["form_id", "peer", "msg_id", "credentials", "requested_info_id", "shipping_option_id", "tip_amount"]

    ID = 0x30c3bc9d
    QUALNAME = "functions.payments.SendPaymentForm"

    def __init__(self, *, form_id: int, peer: "raw.base.InputPeer", msg_id: int, credentials: "raw.base.InputPaymentCredentials", requested_info_id: Union[None, str] = None, shipping_option_id: Union[None, str] = None, tip_amount: Union[None, int] = None) -> None:
        self.form_id = form_id  # long
        self.peer = peer  # InputPeer
        self.msg_id = msg_id  # int
        self.credentials = credentials  # InputPaymentCredentials
        self.requested_info_id = requested_info_id  # flags.0?string
        self.shipping_option_id = shipping_option_id  # flags.1?string
        self.tip_amount = tip_amount  # flags.2?long

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "SendPaymentForm":
        flags = Int.read(b)
        
        form_id = Long.read(b)
        
        peer = TLObject.read(b)
        
        msg_id = Int.read(b)
        
        requested_info_id = String.read(b) if flags & (1 << 0) else None
        shipping_option_id = String.read(b) if flags & (1 << 1) else None
        credentials = TLObject.read(b)
        
        tip_amount = Long.read(b) if flags & (1 << 2) else None
        return SendPaymentForm(form_id=form_id, peer=peer, msg_id=msg_id, credentials=credentials, requested_info_id=requested_info_id, shipping_option_id=shipping_option_id, tip_amount=tip_amount)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.requested_info_id is not None else 0
        flags |= (1 << 1) if self.shipping_option_id is not None else 0
        flags |= (1 << 2) if self.tip_amount is not None else 0
        b.write(Int(flags))
        
        b.write(Long(self.form_id))
        
        b.write(self.peer.write())
        
        b.write(Int(self.msg_id))
        
        if self.requested_info_id is not None:
            b.write(String(self.requested_info_id))
        
        if self.shipping_option_id is not None:
            b.write(String(self.shipping_option_id))
        
        b.write(self.credentials.write())
        
        if self.tip_amount is not None:
            b.write(Long(self.tip_amount))
        
        return b.getvalue()
